@@ -15,8 +15,9 @@ use constant PATH_A=>		[ qw(
 use constant DEBUG=>		0;
 use constant TEST_CLASS=>	'Pod::Text::Color';
 
-BEGIN { plan tests => 10 };
+BEGIN { plan tests => 11 };
 
+#1
 eval "use Class::Runtime";
 if ( $@ ) {
 	ok(0);
@@ -25,6 +26,7 @@ if ( $@ ) {
 	ok(1);
 }
 
+#2
 my $obj = Class::Runtime->new( class=> TEST_CLASS );
 if ( !defined $obj ) {
 	ok(0);
@@ -32,6 +34,7 @@ if ( !defined $obj ) {
 	ok(1);
 }
 
+#3
 my $var = $obj->addPath( path=> PATH_S );
 if ( !defined $var ) {
 	ok(0);
@@ -40,6 +43,7 @@ if ( !defined $var ) {
 }
 warn "$var", "\n" if DEBUG;
 
+#4
 $var = $obj->addPath( path=> PATH_A );
 if ( !defined $var ) {
 	ok(0);
@@ -48,6 +52,7 @@ if ( !defined $var ) {
 }
 warn "$var", "\n" if DEBUG;
 
+#5
 $var = $obj->dropPath( path=> PATH_S );
 if ( !defined $var ) {
 	ok(0);
@@ -56,6 +61,7 @@ if ( !defined $var ) {
 }
 warn "$var", "\n" if DEBUG;
 
+#6
 $var = $obj->dropPath( path=> PATH_A );
 if ( !defined $var ) {
 	ok(0);
@@ -64,6 +70,7 @@ if ( !defined $var ) {
 }
 warn "$var", "\n" if DEBUG;
 
+#7
 $var = $obj->load;
 if ( !defined $var ) {
 	ok(0);
@@ -72,6 +79,7 @@ if ( !defined $var ) {
 }
 warn "$@", "\n" if DEBUG;
 
+#8
 $var = $obj->isLoaded;
 if ( $var == 0 ) {
 	ok(0);
@@ -80,6 +88,16 @@ if ( $var == 0 ) {
 }
 warn "$var", "\n" if DEBUG;
 
+#9
+$var = $obj->invoke( 'new', sentence=> 0, width=> 0 );
+if ( $var->isa('Pod::Text::Color') ) {
+	ok(1);
+} else {
+	ok(0);
+}
+warn "$var", "\n" if DEBUG;
+
+#10
 $var = $obj->unload;
 if ( !defined $var || $var == 0 ) {
 	ok(0);
@@ -88,6 +106,7 @@ if ( !defined $var || $var == 0 ) {
 }
 warn "$@", "\n" if DEBUG;
 
+#11
 $var = $obj->isLoaded;
 if ( $var != 0 ) {
 	ok(0);
@@ -95,4 +114,3 @@ if ( $var != 0 ) {
 	ok(1);
 }
 warn "$var", "\n" if DEBUG;
-
